import { AmazonConnectProviderBase, ConnectLogger, getGlobalProvider, } from "@amazon-connect/core";
import { LifecycleManager, } from "./lifecycle";
import { AppProxy } from "./proxy";
export class AmazonConnectApp extends AmazonConnectProviderBase {
    constructor(config) {
        super({ config, proxyFactory: () => this.createProxy() });
        this.lifecycleManager = new LifecycleManager(this);
        this.logger = new ConnectLogger({ provider: this, source: "app.provider" });
    }
    static init(config) {
        const provider = new AmazonConnectApp(config);
        AmazonConnectApp.initializeProvider(provider);
        return { provider };
    }
    static get default() {
        return getGlobalProvider("AmazonConnectApp has not been initialized");
    }
    createProxy() {
        return new AppProxy(this, this.lifecycleManager);
    }
    onStart(handler, options) {
        this.lifecycleManager.onStart(handler, options);
    }
    onStop(handler) {
        this.lifecycleManager.onStop(handler);
    }
    offStart(handler) {
        this.lifecycleManager.offStart(handler);
    }
    offStop(handler) {
        this.lifecycleManager.offStop(handler);
    }
    sendCloseAppRequest(message) {
        this.getProxy().tryCloseApp(message, false);
    }
    sendError(message, data) {
        this.logger.error(message, data);
    }
    sendFatalError(message, data) {
        this.getProxy().tryCloseApp(message, true, data);
    }
    subscribe(topic, handler) {
        this.getProxy().subscribe(topic, handler);
    }
    unsubscribe(topic, handler) {
        this.getProxy().unsubscribe(topic, handler);
    }
    publish(topic, data) {
        this.getProxy().publish(topic, data);
    }
}
//# sourceMappingURL=amazon-connect-app.js.map