"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AmazonConnectApp = void 0;
const core_1 = require("@amazon-connect/core");
const lifecycle_1 = require("./lifecycle");
const proxy_1 = require("./proxy");
class AmazonConnectApp extends core_1.AmazonConnectProviderBase {
    constructor(config) {
        super({ config, proxyFactory: () => this.createProxy() });
        this.lifecycleManager = new lifecycle_1.LifecycleManager(this);
        this.logger = new core_1.ConnectLogger({ provider: this, source: "app.provider" });
    }
    static init(config) {
        const provider = new AmazonConnectApp(config);
        AmazonConnectApp.initializeProvider(provider);
        return { provider };
    }
    static get default() {
        return (0, core_1.getGlobalProvider)("AmazonConnectApp has not been initialized");
    }
    createProxy() {
        return new proxy_1.AppProxy(this, this.lifecycleManager);
    }
    onStart(handler, options) {
        this.lifecycleManager.onStart(handler, options);
    }
    onStop(handler) {
        this.lifecycleManager.onStop(handler);
    }
    offStart(handler) {
        this.lifecycleManager.offStart(handler);
    }
    offStop(handler) {
        this.lifecycleManager.offStop(handler);
    }
    sendCloseAppRequest(message) {
        this.getProxy().tryCloseApp(message, false);
    }
    sendError(message, data) {
        this.logger.error(message, data);
    }
    sendFatalError(message, data) {
        this.getProxy().tryCloseApp(message, true, data);
    }
    subscribe(topic, handler) {
        this.getProxy().subscribe(topic, handler);
    }
    unsubscribe(topic, handler) {
        this.getProxy().unsubscribe(topic, handler);
    }
    publish(topic, data) {
        this.getProxy().publish(topic, data);
    }
}
exports.AmazonConnectApp = AmazonConnectApp;
//# sourceMappingURL=amazon-connect-app.js.map